@@ -203,7 +203,7 @@ class MailboxHandler extends PFAHandler {
 
     protected function read_from_db_postprocess($db_result) {
         foreach ($db_result as $key => $row) {
-            if (isset($row['quota'])) { # quota could be disabled in $struct
+            if (isset($row['quota']) && is_numeric($row['quota']) && $row['quota'] > -1) { # quota could be disabled in $struct
                 $db_result[$key]['quotabytes'] = $row['quota'];
                 $db_result[$key]['quota'] = divide_quota($row['quota']); # convert quota to MB
             } else {
@@ -216,8 +216,13 @@ class MailboxHandler extends PFAHandler {
 
 
     protected function beforestore() {
+
         if (isset($this->values['quota']) && $this->values['quota'] != -1) {
-            $this->values['quota'] = $this->values['quota'] * Config::read('quota_multiplier'); # convert quota from MB to bytes
+            $multiplier = Config::read('quota_multiplier');
+            if ($multiplier == 0 || !is_numeric($multiplier)) { // or empty string, or null, or false...
+                $multiplier = 1;
+            }
+            $this->values['quota'] = $this->values['quota'] * $multiplier; # convert quota from MB to bytes
         }
 
         $ah = new AliasHandler($this->new, $this->admin_username);
